@@ -49,3 +49,11 @@ from recurring_tags import (
     RecurringTag,
     RecurringTagsIterator
 )
+from recurring_email_receivers import (
+    RecurringEmailReceiver,
+    RecurringEmailReceiversIterator
+)
+from email_templates import (
+    EmailTemplate,
+    EmailTemplatesIterator
+)
